class ScoreUserCategory < ActiveRecord::Base
  belongs_to :score
  belongs_to :user_category

  validates_presence_of :score, :user_category, :value
  validates_uniqueness_of :user_category, scope: :score

  after_commit :calculate_reference

  private

  def calculate_reference
    return 0 if Score.count < 9 || !reputation_hash.values.all? { |x| !x.nil? }

    reference = ScoreCalculatorService.new(self).reputation(reputation_hash)

    user_category.update(reference: reference) if reference.is_a? Float
  end

  def reputation_hash
    {
      'reputation_submitted': Score.where(code: 'reputation_submitted').first.category_value(user_category),
      'reputation_reviews_average_score': Score.where(code: 'reputation_reviews_average_score').first.category_value(user_category),
      'reputation_added_in_best_collections': Score.where(code: 'reputation_added_in_best_collections').first.category_value(user_category),
      'reputation_best_score': Score.where(code: 'reputation_best_score').first.category_value(user_category),
      'reputation_average_score': Score.where(code: 'reputation_average_score').first.category_value(user_category),
      'reputation_reviews_rate': Score.where(code: 'reputation_reviews_rate').first.category_value(user_category),
      # 'reputation_confirmed_complaints': Score.where(code: 'reputation_confirmed_complaints').first.category_value(user_category),
      'reputation_followers': Score.where(code: 'reputation_followers').first.category_value(user_category),
      'reputation_submitted_recently': Score.where(code: 'reputation_submitted_recently').first.category_value(user_category),
      'reputation_collection_score': Score.where(code: 'reputation_collection_score').first.category_value(user_category)
    }
  end
end
